@@ -5,7 +5,7 @@ use warnings;
 package Acme::ConspiracyTheory::Random;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.003';
+our $VERSION   = '0.004';
 
 use Exporter::Shiny qw( theory );
 use List::Util 1.54 ();
@@ -85,6 +85,7 @@ sub shady_group {
 			{ plural => 0, name => 'the global financial elite' },
 			{ plural => 0, name => 'the global scientific elite' },
 			{ plural => 0, name => 'Big Pharma' },
+			{ plural => 0, name => 'Big Tobacco' },
 			{ plural => 1, name => 'the lizard people', shortname => 'the lizardmen' },
 			{ plural => 1, name => 'the grey aliens', shortname => 'the aliens' },
 			{ plural => 1, name => 'the big Hollywood studios', shortname => 'Hollywood' },
@@ -101,6 +102,24 @@ sub shady_group {
 			{ plural => 0, name => 'Twitter' },
 			{ plural => 0, name => 'Facebook' },
 			{ plural => 0, name => 'Google' },
+			{ plural => 0, name => 'the Wall Street establishment', shortname => 'Wall Street' },
+			{ plural => 1, name => 'people at 10 Downing Street', shortname => "Downing Street" },
+			{ plural => 0, name => 'Goldman Sachs' },
+			{ plural => 0, name => 'the London Stock Exchange' },
+			{ plural => 0, name => 'the New York Stock Exchange' },
+			{ plural => 1, name => 'feminists' },
+			{ plural => 1, name => 'Socialists' },
+			sub {
+				my $planet = _RANDOM_(
+					['Nibiru', 'the Nibiruans'],
+					['Venus', 'the Venutians'],
+					['Mars', 'the Martians'],
+					['Pluto', 'the Plutonians'],
+					['the moon', 'the moonlings'],
+					['the Counter-Earth', 'the anti-Earthlings'],
+				);
+				{ plural => 1, name => "aliens from ".$planet->[0], shortname => $planet->[1] };
+			},
 		);
 		
 		no warnings;
@@ -126,6 +145,7 @@ sub real_animal {
 		'whale',
 		'zebra',
 		'frog',
+		'fish',
 	);
 	
 	_MERGE_( $orig_meta, real_animal => $animal );
@@ -141,6 +161,7 @@ sub fake_animal {
 		'mermaid',
 		'werewolf',
 		'dragon',
+		'wyvern',
 	);
 	
 	_MERGE_( $orig_meta, fake_animal => $animal );
@@ -163,6 +184,24 @@ sub objects {
 	return $objects;
 }
 
+sub dark_lord {
+	my $orig_meta = shift // {};
+	
+	my $x = _RANDOM_(
+		'the dark lord',
+		'Beelzebub',
+		'Lord Vader',
+		'Lord Satan',
+		'Thanos',
+		'the devil',
+		'the evil one',
+		'the almighty',
+	);
+	
+	_MERGE_( $orig_meta, dark_lord => $x );
+	return $x;
+}
+
 sub disease {
 	my $orig_meta = shift // {};
 	
@@ -191,6 +230,8 @@ sub chemicals {
 		'Diet Coke',
 		'heavy hydrogen',
 		'5G',
+		'antimatter',
+		'dark matter',
 	);
 	
 	_MERGE_( $orig_meta, chemicals => $chemicals );
@@ -469,6 +510,7 @@ sub misinformation {
 		'the Earth is round',
 		'the Earth goes around the sun',
 		'humans are animals',
+		'birds are dinosaurs',
 		sub {
 			$orig_meta->{topic} = { name => 'the moon', plural => 0 };
 			'men have walked on the moon';
@@ -545,6 +587,38 @@ sub victim {
 	return $victim;
 }
 
+sub physicist {  # and chemists
+	my $orig_meta = shift // {};
+	
+	my $x = _RANDOM_(
+		'Nikola Tesla',
+		'Benjamin Franklin',
+		'Albert Einstein',
+		'Isaac Newton',
+		'Stephen Hawking',
+		'Henry Cavendish',
+	);
+	
+	_MERGE_( $orig_meta, physicist => $x );
+	return $x;
+}
+
+sub biologist {  # and medics
+	my $orig_meta = shift // {};
+	
+	my $x = _RANDOM_(
+		'Charles Darwin',
+		'Edward Jenner',
+		'Robert Koch',
+		'Edward Jenner',
+		'Carl Linneaus',
+		'Alexander Fleming',
+	);
+	
+	_MERGE_( $orig_meta, biologist => $x );
+	return $x;
+}
+
 sub evidence {
 	my $orig_meta = shift // {};
 	
@@ -562,7 +636,7 @@ sub evidence {
 		);
 	}
 	
-	if ( my $v = $orig_meta->{victim} ) {
+	if ( my $v = $orig_meta->{victim} // $orig_meta->{physicist} // $orig_meta->{biologist} ) {
 		push @x, (
 			"$v died too young",
 			"$v sent a letter containing the truth before dying",
@@ -581,6 +655,14 @@ sub evidence {
 		);
 	}
 
+	if ( my $v = $orig_meta->{physicist} // $orig_meta->{biologist} ) {
+		push @x, (
+			"$v isn't mentioned in Aristotle's writing",
+			"$v hasn't given a lecture in months",
+			"$v isn't taken seriously by TRUE SCIENTISTS",
+		);
+	}
+
 	if ( my $c = $orig_meta->{celebrity} ) {
 		if ( $c->{female} ) {
 			push @x, (
@@ -626,7 +708,7 @@ sub evidence {
 			"the $animal looks kind of weird",
 			"nobody has ever seen a $animal in real life",
 			"the $animal obviously isn't native to this planet",
-			sub { "${ \ shady_group() } sacrifice $animal to the dark lord" },
+			sub {	"${ \ shady_group($orig_meta) } sacrifice $animal${\'s'} to ${ \ dark_lord($orig_meta) }" },
 			"the $animal looks bigger in real life",
 			"the $animal makes a funny noise",
 			"Alex Jones did a podcast about the $animal",
@@ -698,6 +780,7 @@ sub evidence {
 		my $have      = $topic->{plural} ? 'have' : 'has';
 		push @x, (
 			"there's hidden clues in the Wikipedia page about $topicname",
+			"THEY let it slip during an edit war in a Wikipedia page about $topicname",
 			"Bible numerology has clues about $topicname",
 			"$topicname $have always been suspicious",
 			"$topicname $have connections to THEM",
@@ -809,10 +892,116 @@ sub hidden_truth {
 	my $orig_meta = shift // {};
 	
 	my $truth = _RANDOM_(
-		'the Earth is flat',
-		'space is fake',
-		'God is real',
-		'reincarnation is true',
+		sub { # wrap classics in a sub so they don't come up too often
+			_RANDOM_(
+				sub {
+					$orig_meta->{topic} = { name => 'geology', plural => 0 };
+					'the Earth is flat';
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'Inner Space (1987)', plural => 0 };
+					'space is fake';
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'theology', plural => 0 };
+					'God is real';
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'Buddhism', plural => 0 };
+					'reincarnation is true';
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'germs', plural => 1 };
+					"germs aren't real";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'viruses', plural => 1 };
+					"viruses aren't real";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'MKUltra', plural => 1 };
+					"MKUltra is still happening";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'Jeffrey Epstein', plural => 1 };
+					"Epstein didn't kill himself";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'Stonehenge', plural => 0 };
+					$orig_meta->{random_place} //= 'Somerset';
+					"the aliens built Stonehenge";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'the Sphinx', plural => 0 };
+					$orig_meta->{random_place} //= 'Egypt';
+					"the aliens built the Pyramids";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'Loch Ness', plural => 0 };
+					$orig_meta->{random_place} //= 'Scotland';
+					"the Loch Ness monster is real";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'grain farming', plural => 0 };
+					$orig_meta->{random_place} //= 'Alabama';
+					"crop circles are caused by aliens";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'kidnapping', plural => 0 };
+					$orig_meta->{random_place} //= 'Alabama';
+					"aliens abduct people for probing";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'steal beams', plural => 1 };
+					$orig_meta->{random_place} //= 'New York';
+					"9/11 was an inside job";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'glaciers', plural => 1 };
+					$orig_meta->{random_place} //= 'Greenland';
+					"global warming is a hoax";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'gas chambers', plural => 1 };
+					$orig_meta->{random_place} //= 'Germany';
+					"the holocaust never happened";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'fascism', plural => 0 };
+					$orig_meta->{random_place} //= 'Australia';
+					"Antifa International have been starting wildfires";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'phantom time', plural => 0 };
+					"the years between 614 and 911 never happened";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'Nazis', plural => 1 };
+					"there is a Nazi base on the moon";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'Nazis', plural => 1 };
+					"there is a Nazi base in Antarctica";
+				},
+			);
+		},
+		sub {
+			$orig_meta->{topic} = { name => 'the Mandela effect', plural => 0 };
+			_RANDOM_(
+				'Looney Tunes used to be Looney Toons',
+				'the Berenstain Bears used to be spelled Berenstein',
+				'Curious George used to have a tail',
+				'Febreze used to have another E in it',
+				'Froot Loops used to be Fruit Loops',
+				'the Monopoly man is supposed to have a monacle',
+				'Kitkat used to have a hyphen',
+				'the Mona Lisa used to smile more',
+				'C-3PO never used to have a silver leg',
+				'Darth Vader said Luke I Am Your Father',
+				'We Are the Champions used to say "of the world" at the end',
+				'the USA used to have 52 states',
+			);
+		},
 		sub {
 			my $cryptids = cryptids( $orig_meta );
 			"$cryptids are real";
@@ -822,23 +1011,25 @@ sub hidden_truth {
 			my $group    = shady_group( $orig_meta );
 			"$group are $cryptids";
 		},
-		sub {
-			$orig_meta->{topic} = { name => 'germs', plural => 1 };
-			"germs aren't real"
-		},
-		sub {
-			$orig_meta->{topic} = { name => 'viruses', plural => 1 };
-			"viruses aren't real"
-		},
 		sub {
 			my $objects = objects( $orig_meta );
 			"$objects are sentient";
 		},
+		sub {
+			my $things = _RANDOM_( 'electrons', 'protons' );
+			$orig_meta->{topic} = { name => $things, plural => 1 };
+			"$things are not real particles, they are just the terminal lines of a dieletric pulse";
+		},
 		sub {
 			my $celebrity = celebrity( $orig_meta );
 			my $long_time = a_long_time( $orig_meta );
 			"$celebrity has been drinking the blood of infants $long_time to stay looking young";
 		},
+		sub {
+			my $celebrity = celebrity( $orig_meta );
+			$orig_meta->{topic} = { name => 'cross-dressing', plural => 0 };
+			"$celebrity is transsexual";
+		},
 		sub {
 			my $celebrity = celebrity( $orig_meta );
 			my $consequence = _RANDOM_(
@@ -997,6 +1188,18 @@ sub hidden_truth {
 			my $victim = $orig_meta->{victim} // victim( $orig_meta );
 			"$fiction was really written by $victim";
 		},
+		sub {
+			my $p = random_place( $orig_meta );
+			my $extinct = _RANDOM_(
+				'dinosaur',
+				'mammoth',
+				'sabre-tooth tiger',
+				'Tasmanian tiger',
+				'pterodactyl',
+			);
+			$orig_meta->{real_animal} //= $extinct;
+			"the $extinct is not extinct and there is a colony in $p";
+		},
 	);
 	
 	_MERGE_( $orig_meta, hidden_truth => $truth );
@@ -1070,12 +1273,12 @@ sub theory {
 			
 			my $truth = hidden_truth( $orig_meta );
 			
-			my $explanation = _RANDOM_(
+			my $explanation = _UCFIRST_ _RANDOM_(
 				sub {
 					my $group2 = shady_group( $orig_meta );
 					$orig_meta->{antagonists} = $orig_meta->{shady_group};
 					
-					_UCFIRST_ "$victim learnt the truth from $group2";
+					"$victim learnt the truth from $group2";
 				},
 				"Nobody knows how $victim found out",
 				"$victim found out because they were the source of all knowledge",
@@ -1137,9 +1340,10 @@ sub theory {
 			$orig_meta->{protagonists} = $orig_meta->{shady_group};
 			my $are = $orig_meta->{protagonists}->{plural} ? 'are' : 'is';
 			
-			my $place = random_place( $orig_meta );
+			my $place    = random_place( $orig_meta );
+			my $darklord = dark_lord( $orig_meta );
 			
-			_UCFIRST_ "$group $are abducting orphan children from $place to sacrifice them to their dark overlord.";
+			_UCFIRST_ "$group $are abducting orphan children from $place to sacrifice them to $darklord.";
 		},
 		sub {
 			my $group = shady_group( $orig_meta );
@@ -1150,6 +1354,144 @@ sub theory {
 			
 			_UCFIRST_ "$group $have $resource.";
 		},
+		sub {
+			my $group = shady_group( $orig_meta );
+			$orig_meta->{protagonists} = $orig_meta->{shady_group};
+			
+			my $physicist = physicist( $orig_meta );
+			
+			my $fact = _RANDOM_(
+				sub {
+					$orig_meta->{topic} = { name => 'bathroom scales', plural => 1 };
+					'electrons have mass';
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'weighing scales', plural => 1 };
+					"protons don't have mass";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'water', plural => 0 };
+					'water is its own element';
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'geocentrism', plural => 0 };
+					'the sun goes round the Earth';
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'the moon', plural => 0 };
+					'the moon is a hologram';
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'camembert', plural => 0 };
+					'the moon is made of cheese';
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'the man in the moon', plural => 0 };
+					'the man in the moon is a real man';
+				},
+				sub {
+					my $chem = chemicals( $orig_meta );
+					$orig_meta->{topic} = { name => 'the periodic table', plural => 0 };
+					"element 119 is $chem";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'air', plural => 0 };
+					"air isn't real";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'vacuum cleaners', plural => 0 };
+					"space isn't a vacuum because then it would suck all the air";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'the firmament', plural => 0 };
+					"there is a dome over the flat Earth";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'Satan', plural => 0 };
+					'the axis of evil in the cosmic microwave background was put there by Satan';
+				},
+			);
+			
+			my $solution = _UCFIRST_ _RANDOM_(
+				"They paid $group to kill him.",
+				"$group helped cover up the truth.",
+				"$group threatened to kill him to keep him quiet.",
+				"He was a member of $group so they knew he would keep quiet.",
+			);
+			
+			my $destruction = _RANDOM_(
+				"all of modern physics",
+				'our understanding of the universe',
+				"the Big Bang 'theory'",
+			);
+			
+			_UCFIRST_ "$physicist discovered that $fact but the scientific establishment is suppressing it because it would destroy $destruction. $solution";
+		},
+		sub {
+			my $group = shady_group( $orig_meta );
+			$orig_meta->{protagonists} = $orig_meta->{shady_group};
+			
+			my $biologist = biologist( $orig_meta );
+			
+			my $fact = _RANDOM_(
+				sub {
+					$orig_meta->{topic} = { name => 'pandas', plural => 1 };
+					'pandas are really just fat racoons';
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'spaghetti', plural => 1 };
+					"spaghetti is a type of worm";
+				},
+				sub {
+					$orig_meta->{celebrity} //= { name => 'Louis Armstrong', female => 0 };
+					$orig_meta->{topic} = { name => 'snakes', plural => 1 };
+					"snakes like jazz music";
+				},
+				sub {
+					$orig_meta->{real_place} //= 'Antarctica';
+					$orig_meta->{topic} = { name => 'penguins', plural => 1 };
+					"penguins can fly but they get nervous when people are watching";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'DNA', plural => 0 };
+					"the 10 commandments are encoded in human DNA";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'essential oils', plural => 1 };
+					"essential oils cure all diseases";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'vaccines', plural => 1 };
+					"essential oils cure autism";
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'anger managemment', plural => 0 };
+					"wasps are just angry bees";
+				},
+				sub {
+					my $animal = real_animal( $orig_meta );
+					$orig_meta->{topic} = { name => 'space flight', plural => 0 };
+					"$animal DNA comes from space";
+				},
+			);
+			
+			my $solution = _UCFIRST_ _RANDOM_(
+				"They paid $group to kill him.",
+				"$group helped cover up the truth.",
+				"$group threatened to kill him to keep him quiet.",
+				"He was a member of $group so they knew he would keep quiet.",
+			);
+			
+			my $destruction = _RANDOM_(
+				"the 'theory' of evolution",
+				'modern medicine',
+				"the germ theory of disease",
+				"our understanding of DNA",
+				'creation science',
+			);
+			
+			_UCFIRST_ "$biologist discovered that $fact but the scientific establishment is suppressing it because it would destroy $destruction. $solution";
+		},
 		sub {
 			my $group = shady_group( $orig_meta );
 			$orig_meta->{protagonists} = $orig_meta->{shady_group};
@@ -1216,6 +1558,9 @@ sub theory {
 			},
 			"$group2 $know the truth but $group1 have threatened them to keep them silent.",
 			"$group2 were helping them until $group1 betrayed them.",
+			"$group2 were helping them for a while.",
+			"$group2 were originally opposed to this but they're now in on it.",
+			"$group2 are trying to get evidence to prove it.",
 		);
 	}
 
